package com.ningdatech.pmapi.projectlib.manage;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ningdatech.basic.model.PageVo;
import com.ningdatech.basic.util.CollUtils;
import com.ningdatech.pmapi.projectlib.model.entity.Project;
import com.ningdatech.pmapi.projectlib.model.req.ProjectLibListReq;
import com.ningdatech.pmapi.projectlib.model.vo.ProjectLibListItemVO;
import com.ningdatech.pmapi.projectlib.service.INdProjectService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Component;

import java.util.List;

import static com.ningdatech.pmapi.common.utils.BizUtils.notBlank;
import static com.ningdatech.pmapi.common.utils.BizUtils.notNull;

/**
 * <p>
 * ProjectLibManage
 * </p>
 *
 * @author WendyYang
 * @since 14:19 2023/2/1
 */
@Component
@RequiredArgsConstructor
public class ProjectLibManage {

    private final INdProjectService projectService;

    private LambdaQueryWrapper<Project> projectLibQuery(ProjectLibListReq req) {
        LambdaQueryWrapper<Project> query = Wrappers.lambdaQuery(Project.class);
        notBlank(req.getProjectName(), w -> query.like(Project::getProjectName, w));
        notNull(req.getProjectType(), w -> query.eq(Project::getProjectType, w));
        notNull(req.getProjectYear(), w -> query.eq(Project::getProjectYear, w));
        // 申报金额 批复金额
        notNull(req.getApproveAmountMin(), w -> query.ge(Project::getApprovalAmount, w));
        notNull(req.getApproveAmountMax(), w -> query.le(Project::getApprovalAmount, w));

        notNull(req.getDeclareAmountMax(), w -> query.le(Project::getDeclareAmount, w));
        notNull(req.getDeclareAmountMin(), w -> query.ge(Project::getDeclareAmount, w));
        // 状态查询
        notNull(req.getStatus1st(), w -> query.ge(Project::getStage, w));
        notNull(req.getStatus2nd(), w -> query.ge(Project::getStatus, w));

        notNull(req.getCreateOnMin(), w -> query.ge(Project::getCreateOn, w));
        notNull(req.getCreateOnMax(), w -> query.le(Project::getCreateOn, w));

        notBlank(req.getBuildUnit(), w -> query.like(Project::getBuildUnitName, w));

        query.orderByDesc(Project::getUpdateOn, Project::getCreateOn);
        // TODO 区域编码处理
        return query;
    }

    public PageVo<ProjectLibListItemVO> projectLibList(ProjectLibListReq req) {
        LambdaQueryWrapper<Project> query = projectLibQuery(req);
        Page<Project> page = projectService.page(req.page(), query);
        long total;
        if ((total = page.getTotal()) == 0) {
            return PageVo.empty();
        }
        List<ProjectLibListItemVO> records = CollUtils.convert(page.getRecords(), w -> {
            ProjectLibListItemVO item = new ProjectLibListItemVO();
            item.setId(w.getId());
            item.setProjectName(w.getProjectName());
            item.setCreateOn(w.getCreateOn());
            item.setDeclaredAmount(w.getDeclareAmount());
            item.setStatus1st(w.getStage());
            item.setStatus2nd(w.getStatus());
            item.setProjectType(w.getProjectType());
            item.setProjectYear(w.getProjectYear());
            item.setBuildUnit(w.getBuildUnitName());
            item.setBizDomain(w.getBizDomain());
            return item;
        });
        return PageVo.of(records, total);
    }

}
